C.hr DGMABP
C@
C....*...1.........2.........3.........4.........5.........6.........7.*
C     DGMABP   8/20/73
C
C     PURPOSE
C     POSTMULTIPLY A BY THE TRANSPOSE OF B (R=AB').
C
C     USAGE
C     CALL DGMABP(A,B,R,N,M,L)
C
C     ARGUMENTS
C     A - INPUT N BY M MATRIX STORED COLUMNWISE (STORAGE MODE 0).
C         REAL*8
C     B - INPUT L BY M MATRIX STORED COLUMNWISE (STORAGE MODE 0).
C         REAL*8
C     R - OUTPUT N BY L MATRIX STORED COLUMNWISE (STORAGE MODE 0).
C         REAL*8
C     N - NUMBER OF ROWS OF A AND R.
C         INTEGER*4
C     M - NUMBER OF COLUMNS OF A AND B.
C         INTEGER*4
C     L - NUMBER OF ROWS OF B AND COLUMNS OF R.
C         INTEGER*4
C
C
      SUBROUTINE DGMABP(A,B,R,N,M,L)
      implicit real*8 (a-h,o-z)
      save
      REAL*8 A(N,M),B(L,M),R(N,L)
      DO 10 I=1,N
      DO 10 J=1,L
      R(I,J)=0.D0
      DO 10 K=1,M
10    R(I,J)=R(I,J)+A(I,K)*B(J,K)
      RETURN
      END
